package cn.iocoder.yudao.module.bpm.controller.admin.oa;

import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.module.bpm.controller.admin.oa.vo.leave.BpmOALeaveCreateReqVO;
import cn.iocoder.yudao.module.bpm.controller.admin.oa.vo.leave.BpmOALeavePageReqVO;
import cn.iocoder.yudao.module.bpm.controller.admin.oa.vo.leave.BpmOALeaveRespVO;
import cn.iocoder.yudao.module.bpm.controller.admin.oa.vo.worktask.BpmOAWorkTaskReqVO;
import cn.iocoder.yudao.module.bpm.controller.admin.oa.vo.worktask.BpmOAWorkTaskRespVO;
import cn.iocoder.yudao.module.bpm.convert.oa.BpmOALeaveConvert;
import cn.iocoder.yudao.module.bpm.convert.oa.BpmOAWorkTaskConvert;
import cn.iocoder.yudao.module.bpm.dal.dataobject.oa.BpmOALeaveDO;
import cn.iocoder.yudao.module.bpm.dal.dataobject.oa.BpmOAWorkTaskDO;
import cn.iocoder.yudao.module.bpm.service.oa.BpmOALeaveService;
import cn.iocoder.yudao.module.bpm.service.oa.BpmOAWorkTaskService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.validation.Valid;

import java.util.List;

import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import static cn.iocoder.yudao.framework.security.core.util.SecurityFrameworkUtils.getLoginUserId;

/**
 * OA 任务分配 Controller
 *
 * @author 姚君

 */
@Tag(name = "管理后台 - OA 任务分配")
@RestController
@RequestMapping("/bpm/oa/worktask")
@Validated
public class BpmOAWorkTaskController {

    @Resource
    private BpmOAWorkTaskService workTaskService;

    @PostMapping("/create")
    @Operation(summary = "创建任务分配")
    public CommonResult<Long> createLeave(@Valid @RequestBody BpmOAWorkTaskReqVO createReqVO) {
        return success(workTaskService.createWorkTask(getLoginUserId(), createReqVO));
    }

    @GetMapping("/get")
    @Operation(summary = "获得任务分配")
    @Parameter(name = "id", description = "编号", required = true, example = "1024")
    public CommonResult<BpmOAWorkTaskRespVO> getLeave(@RequestParam("id") Long id) {
        BpmOAWorkTaskDO workTask = workTaskService.getWorkTask(id);
        return success(BpmOAWorkTaskConvert.INSTANCE.convert(workTask));
    }

    @PostMapping("/add")
    @Operation(summary = "添加任务跟踪数据【全量传】")
    public CommonResult<Boolean> addTrackInfo(@RequestBody List<BpmOAWorkTaskRespVO.TrackInfo> trackInfos) {
        workTaskService.addTrackInfo(getLoginUserId(), trackInfos) ;
        return success(true);
    }

    @PostMapping("/update")
    @Operation(summary = "更新工作任务的状态和进度")
    public CommonResult<Boolean> updateWorkTask(@RequestBody BpmOAWorkTaskReqVO createReqVO) {
        workTaskService.updateWorkTask(getLoginUserId(), createReqVO) ;
        return success(true);
    }

}
