package cn.iocoder.yudao.module.bpm.controller.admin.oa.vo.worktask;
import cn.iocoder.yudao.module.bpm.controller.admin.oa.vo.BpmOABaseRespVO;
import cn.iocoder.yudao.module.bpm.controller.admin.oa.vo.reimbursement.ReimbursementDTO;
import cn.iocoder.yudao.module.bpm.controller.admin.upload.UploadUserFile;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.ToString;
import org.springframework.format.annotation.DateTimeFormat;

import javax.validation.constraints.NotNull;
import java.math.BigDecimal;
import java.time.LocalDateTime;
import java.util.List;

import static cn.iocoder.yudao.framework.common.util.date.DateUtils.FORMAT_YEAR_MONTH_DAY_HOUR_MINUTE_SECOND;

@Schema(description = "管理后台 - 报销响应数据 Response VO")
@Data
@EqualsAndHashCode(callSuper = true)
@ToString(callSuper = true)
public class BpmOAWorkTaskRespVO extends BpmOABaseRespVO {

    @Schema(description = "任务名称", requiredMode = Schema.RequiredMode.REQUIRED)
    @NotNull(message = "任务名称不能为空")
    private String taskName;

    @Schema(description = "任务内容", requiredMode = Schema.RequiredMode.REQUIRED)
    @NotNull(message = "任务内容不能为空")
    private String taskContent;

    @Schema(description = "任务的开始时间", requiredMode = Schema.RequiredMode.REQUIRED)
    @NotNull(message = "截止时间不能为空")
    @DateTimeFormat(pattern = FORMAT_YEAR_MONTH_DAY_HOUR_MINUTE_SECOND)
    private LocalDateTime startTime;

    @Schema(description = "任务的截止时间", requiredMode = Schema.RequiredMode.REQUIRED)
    @NotNull(message = "截止时间不能为空")
    @DateTimeFormat(pattern = FORMAT_YEAR_MONTH_DAY_HOUR_MINUTE_SECOND)
    private LocalDateTime endTime;

    @Schema(description = "责任人名称", requiredMode = Schema.RequiredMode.REQUIRED)
    @NotNull(message = "责任名称不能为空")
    private Long userName;

    @Schema(description = "部门名称", requiredMode = Schema.RequiredMode.REQUIRED)
    @NotNull(message = "部门名称不能为空")
    private Long deptName;

    @Schema(description = "任务进度百分比", requiredMode = Schema.RequiredMode.REQUIRED)
    @NotNull(message = "任务进度百分比")
    private Long schedule ;

    @Schema(description = "工作任务状态", requiredMode = Schema.RequiredMode.REQUIRED, example = "1:待启动，2:进行中，3.已完成，4.延期, 5.搁置")
    @NotNull(message = "工作任务状态")
    private Integer workTaskStatus ;

    @Schema(description = "跟踪内容集合")
    private List<TrackInfo> trackInfos ;

    @Schema(description = "任务跟踪信息")
    @Data
    public static class TrackInfo {

        @Schema(description = "跟踪人", example = "126")
        private Long TrackUserId;

        @Schema(description = "跟踪内容", example = "11111112122222")
        private String TrackContent;

        @Schema(description = "跟踪内容提交时间", example = "2024-05-12 12:00:44")
        private LocalDateTime trackTime;
    }


}
