package cn.iocoder.yudao.module.bpm.service.oa;

import cn.iocoder.yudao.module.bpm.api.task.BpmProcessInstanceApi;
import cn.iocoder.yudao.module.bpm.api.task.dto.BpmProcessInstanceCreateReqDTO;
import cn.iocoder.yudao.module.bpm.controller.admin.oa.vo.worktask.BpmOAWorkTaskReqVO;
import cn.iocoder.yudao.module.bpm.controller.admin.oa.vo.worktask.BpmOAWorkTaskRespVO;
import cn.iocoder.yudao.module.bpm.controller.admin.upload.UploadUserFile;
import cn.iocoder.yudao.module.bpm.convert.oa.BpmOAWorkTaskConvert;
import cn.iocoder.yudao.module.bpm.dal.dataobject.oa.BpmOAWorkTaskDO;
import cn.iocoder.yudao.module.bpm.dal.mysql.oa.BpmOAWorkTaskMapper;
import cn.iocoder.yudao.module.bpm.enums.task.BpmProcessInstanceResultEnum;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.validation.annotation.Validated;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.bpm.enums.ErrorCodeConstants.OA_WORK_TASK_NOT_EXISTS;

/**
 * OA 请假申请 Service 实现类
 *
 * @author jason

 */
@Service
@Validated
public class BpmOAWorkTaskServiceImpl extends BpmOABaseService implements BpmOAWorkTaskService {

    /**
     * OA 请假对应的流程定义 KEY
     */
    public static final String PROCESS_KEY = "oa_work_task";

    @Resource
    private BpmOAWorkTaskMapper workTaskMapper;

    @Resource
    private BpmProcessInstanceApi processInstanceApi;

    @Override
    @Transactional(rollbackFor = Exception.class)
    public Long createWorkTask(Long userId, BpmOAWorkTaskReqVO createReqVO) {
        BpmOAWorkTaskDO workTask = BpmOAWorkTaskConvert.INSTANCE.convert(createReqVO)
                .setFromUserId(userId)
                .setWorkTaskStatus(1) //默认待启动状态
                .setReceiverUserId(createReqVO.getUserId())
                .setResult(BpmProcessInstanceResultEnum.PROCESS.getResult());
        workTaskMapper.insert(workTask);

        // 发起 BPM 流程
        Map<String, Object> processInstanceVariables = new HashMap<>();
        String processInstanceId = processInstanceApi.createProcessInstance(userId,
                new BpmProcessInstanceCreateReqDTO().setProcessDefinitionKey(PROCESS_KEY)
                        .setVariables(processInstanceVariables).setBusinessKey(String.valueOf(workTask.getId()))).getCheckedData();

        // 将工作流的编号，更新到 OA 请假单中
        workTaskMapper.updateById(new BpmOAWorkTaskDO().setId(workTask.getId()).setProcessInstanceId(processInstanceId));

        List<UploadUserFile> fileItems = createReqVO.getFileItems() ;
        //这里的逻辑，如果fileItems不为空，且有数据，那么说明是上传了附件的，则需要更工作流文件表对应的实例Id
        if (fileItems != null && !fileItems.isEmpty()) {
            uploadBpmFileProcessInstanceId(processInstanceId,fileItems) ;
        }
        return workTask.getId();
    }

    @Override
    public void updateWorkTaskResult(Long id, Integer result) {
        validateLeaveExists(id);
        //bpm流程设置成已完成，需要将任务自生的状态设置成已完成
        workTaskMapper.updateById(new BpmOAWorkTaskDO().setId(id).setResult(result).setWorkTaskStatus(3));
    }

    private void validateLeaveExists(Long id) {
        if (workTaskMapper.selectById(id) == null) {
            throw exception(OA_WORK_TASK_NOT_EXISTS);
        }
    }

    @Override
    public BpmOAWorkTaskDO getWorkTask(Long id) {
        return workTaskMapper.selectById(id);
    }

    @Override
    public void addTrackInfo(Long id, List<BpmOAWorkTaskRespVO.TrackInfo> trackInfos) {
        validateLeaveExists(id);
        workTaskMapper.updateById(new BpmOAWorkTaskDO().setId(id).setTrackInfos(trackInfos));
    }

    @Override
    public void updateWorkTask(Long id, BpmOAWorkTaskReqVO createReqVO) {
        validateLeaveExists(id);
        //更新任务进度  和  任务状态
        workTaskMapper.updateById(new BpmOAWorkTaskDO().setId(id).setWorkTaskStatus(createReqVO.getWorkTaskStatus()).setSchedule(createReqVO.getSchedule()));
    }
}
